@@ -17,7 +17,7 @@ except ImportError:
 #import pandas as pd
 
 def make_plot(*args, **kwargs):
-    subplot = {'subtype': 'splot',
+    subplot = {'subtype': 'plot',
             'cmd': [] }
     subplot["attribute"] = collections.OrderedDict()
 
@@ -30,7 +30,7 @@ def make_plot(*args, **kwargs):
     return subplot
 
 def make_splot(*args, **kwargs):
-    subplot = {'subtype': 'plot',
+    subplot = {'subtype': 'splot',
             'cmd': [] }
     subplot["attribute"] = collections.OrderedDict()
 
@@ -45,7 +45,7 @@ def multiplot(*args, **kwargs):
     @args: the subplot object list;
     @kwargs: the setting options that need to be set before call plot;
     '''
-    g = gnuplot.Gnuplot()
+    g = Gnuplot()
 
     for k,v in kwargs.items():
         #print('set %s %s' %(k, v))
@@ -65,9 +65,9 @@ def multiplot(*args, **kwargs):
         cmd = subplot["cmd"]
         c = subplot["subtype"]
         for cmd in subplot["cmd"]:
-            c += ' $Mydata %s, ' %(cmd)
-        #print(c)
-        g.cmd(c)
+            c += ' %s,' %(cmd)
+        #print("log multiplot(): ", c.rstrip(','))
+        g.cmd(c.rstrip(','))
         # multiplot automatically unset all the label after one subplot.
         g.cmd('unset for [i=1:200] label i')
     g.reset()
